@@ -1,9 +1,18 @@
-from ..core import dataset
-import xarray as xr
-import numpy as np
-from . import gen_ds
+import warnings
 from timeit import timeit
 
+import numpy as np
+import pytest
+import xarray as xr
+
+from ..core import dataset
+from . import gen_ds
+
+try:
+    import matplotlib  # type: ignore
+except ImportError:
+    matplotlib = None
+
 
 def test_sel():
     ds = xr.Dataset()
@@ -427,6 +436,30 @@ class Test_eval_at_rpz(object):
             assert result["var"].dims == ("x", "y")
             assert result["var"].shape == (5, 6)
 
+    def test_plot_rz(self):
+        """
+        Ensure no error is raised.
+        """
+        if matplotlib is None:
+            pytest.skip("matplotlib missing")
+        self.setup()
+        ret = self.ds.emc3.plot_rz(key=None, phi=0.3)
+        assert isinstance(ret, matplotlib.collections.QuadMesh)
+
+    def test_plot_Rz(self):
+        """
+        Ensure no error is raised.
+        """
+        if matplotlib is None:
+            pytest.skip("matplotlib missing")
+        self.setup()
+        with warnings.catch_warnings(record=True) as w:
+            ret = self.ds.emc3.plot_Rz(key=None, phi=0.3)
+            assert len(w) == 1
+            assert issubclass(w[-1].category, DeprecationWarning)
+            assert "plot_rz" in str(w[-1].message)
+        assert isinstance(ret, matplotlib.collections.QuadMesh)
+
 
 if __name__ == "__main__":
     Test_eval_at_rpz().test_nan_value()
